locale = {
    [":("] = ":(",
    ["!!!"] = "!!!",
    ["..."] = "...",
    ["Accuracy Bonus!"] = "Bonus za celność",
    ["Achievement Unlocked"] = "Zdobyłeś Osiągnięcie!", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_That_Sinking_Feeling, Tumbler
    ["a Hedgewars mini-game"] = "Mini gra", -- Space_Invasion, The_Specialists
    ["Aiming Practice"] = "Potrenuj celność",
    ["Ammo"] = "Amunicja",
    ["Ammo Depleted!"] = "Koniec amunicji!",
--      ["ammo extended!"] = "",
    ["Ammo is reset at the end of your turn."] = "Amunicja jest resetowana przy końcu tury.",
    ["Ammo Maniac!"] = "Nabojowy Maniak!",
    ["Available points remaining: "] = "Pozostały następujące punkty: ",
--      ["[Backspace]"] = "",
--      ["Bamboo Thicket"] = "",
    ["Barrel Eater!"] = "Pożeracz Beczek!",
    ["Barrel Launcher"] = "Wyrzutnia Beczek",
    ["Bat balls at your enemies and|push them into the sea!"] = "Uderzaj piłkami w swoich przeciwników|i strącaj ich do wody!",
    ["Bat your opponents through the|baskets and out of the map!"] = "Uderzaj swoich przeciwników|wyrzucając przez kosz, poza mapę!",
    ["Bazooka Training"] = "Trening bazooki",
    ["Best laps per team: "] = "Najszybsze okrążenie drużyny: ",
    ["Best Team Times: "] = "Najlepszy czas zespołów",
    ["Bloody Rookies"] = "Żółtodzioby",
    ["Boom!"] = "BUM!",
    ["BOOM!"] = "BUM!",
    ["Boss defeated!"] = "Boss pokonany!",
    ["Boss Slayer!"] = "Pogromca bossów",
    ["Build a track and race."] = "Zbuduj trasę i ścigaj się.",
    ["CAPTURE THE FLAG"] = "PRZECHWYĆ FLAGĘ",
    ["Careless"] = "Nieostrożny",
    ["Change Weapon"] = "Zmień broń",
    ["Clumsy"] = "Fajtłapa",
    ["Codename: Teamwork"] = "Kryptonim: Praca zespołowa",
    ["Complete the track as fast as you can!"] = "Ukończ trasę tak szybko jak tylko potrafisz!",
    ["Congratulations!"] = "Gratulacje",
    ["Congratulations! You've eliminated all targets|within the allowed time frame."] = "Gratulacje! Zniszczyłeś wszystkie cele przed upłynięciem czasu.",  
    ["Control pillars to score points."] = "Kontroluj filary by zdobyć punkty",
    ["Cybernetic Empire"] = "Cybernetyczne Imperium",
    ["DAMMIT, ROOKIE! GET OFF MY HEAD!"] = "Młody!!! Złaź z mojej głowy!!!",
    ["DAMMIT, ROOKIE!"] = "Żółtodziobie!",
    ["Dangerous Ducklings"] = "Niebezpieczne Kaczory",
--      ["Deadweight"] = "",
    ["Demolition is fun!"] = "Rozwałka jest fajna!",
--      ["Depleted Kamikaze!"] = "",
    ["Destroy invaders to score points."] = "Zabijaj najeźdźców by zdobyć punkty.",
    ["Double Kill!"] = "Podwójna śmierć!",
    ["Drone Hunter!"] = "Łowca dronów",
--      ["Drowner"] = "",
    ["Each turn you get 1-3 random weapons"] = "Z każdą turą dostaniesz 1-3 bronie",
    ["Each turn you get one random weapon"] = "Z każdą turą dostaniesz losową broń",
    ["Eliminate all enemies"] = "Wyeliminuj wszystkich przeciwników",
    ["Eliminate all targets before your time runs out.|You have unlimited ammo for this mission."] = "Zniszcz wszystkie cele zanim upłynie czas.|W tej misji masz nieskończoną ilość amunicji.", 
    ["Eliminate Poison before the time runs out"] = "Zabij Truciciela zanim skończy się czas",
    ["Eliminate the Blue Team"] = "Zniszcz niebieską drużynę",
    ["Eliminate the enemy before the time runs out"] = "Wyeliminuj przeciwnika przed upłynięciem czasu.", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_Newton_and_the_Hammock
    ["Eliminate the enemy hogs to win."] = "Wybij jeże przeciwnika by wygrać.",
    ["Eliminate the enemy specialists."] = "Zabij specjalistów wroga.",
    ["- Eliminate Unit 3378 |- Feeble Resistance must survive"] = "- Rozwal Jednostkę 3378 |- Twoja drużyna musi przetrwać",
    ["Energetic Engineer"] = "Energetyczny Inżynier",
    ["Enjoy the swim..."] = "Popływaj trochę...",
    ["[Enter]"] = "[Enter]",
    ["Fastest lap: "] = "Najszybsze okrążenie: ",
    ["Feeble Resistance"] = "Ruch Oporu",
    ["Fire"] = "Ogień",
    ["Flag captured!"] = "Flaga przechwycona!",
    ["Flag respawned!"] = "Flaga przywrócona!",
    ["Flag returned!"] = "Flaga odzyskana!",
    ["Flags, and their home base will be placed where each team ends their first turn."] = "Flagi i baza zostaną umieszczone tam gdzie zespół zakończy swą pierwszą turę.",
--      ["Flamer"] = "",
--      ["Friendly Fire!"] = "",
    ["fuel extended!"] = "zdobyto paliwo",
    ["GAME BEGUN!!!"] = "GRA ROZPOCZĘTA!!!",
    ["Game Modifiers: "] = "Modyfikatory: ",
    ["GAME OVER!"] = "KONIEC GRY!",
    ["Game Started!"] = "Gra Rozpoczęta",
    ["Get on over there and take him out!"] = "Dostań się tam i go wykończ!",
    ["Goal"] = "Gol",
    ["GO! GO! GO!"] = "RUCHY! RUCHY! RUCHY!",
    ["Good birdy......"] = "Dooobry ptaszek...",
    ["Good luck out there!"] = "Powodzenia!",
    ["Good so far!"] = "Jak dotąd idzie dobrze!",
    ["Good to go!"] = "Gotowi do akcji!",
    ["GOTCHA!"] = "MAM CIĘ!",
    ["Grab Mines/Explosives"] = "Chwyć miny/beczki",
    ["Hahahaha!"] = "Hahahaha!",
    ["Haha, now THAT would be something!"] = "Haha, to było by COŚ",
    [" Hapless Hogs left!"] = " Nieszczęsne Jeże pozostały",
    ["Hapless Hogs"] = "Nieszczęsne Jeże",
    ["Health crates extend your time."] = "Apteczki dodają czas.",
--      ["Heavy"] = "",
    ["Hedgewars-Basketball"] = "Hedgewars-Koszykówka",
    ["Hedgewars-Knockball"] = "Hedgewars-Knockball",
    ["Heh, it's not that bad."] = "Heh, nie jest aż tak źle.",
    ["Hit Combo!"] = "Combo!",
    ["Hmmm..."] = "Hmmmm...",
    ["Hooray!"] = "Hurraaa!",
    ["Hunter"] = "Strzelec",  
    ["Instructor"] = "Instruktor",  
    ["invaders destroyed"] = "najeźdźców zniszczonych",
    ["It's a good thing SUDDEN DEATH is 99 turns away..."] = "Jak to dobrze, że Nagła Śmierć jest dopiero za 99 tur...",
    ["Jumping is disabled"] = "Skakanie jest niemożliwe",
--      ["Kamikaze Expert!"] = "",
    ["Keep it up!"] = "Tak trzymaj!",
    ["Killing spree!"] = "Masakra!",
    ["KILLS"] = "Zabicia",
    ["Last Target!"] = "Ostatni cel!",
    ["[Left Shift]"] = "[Lewy Shift]",
    ["Listen up, maggot!!"] = "Słuchaj mnie, gnido!",
    ["Lively Lifeguard"] = "Ratownik!",
--      ["Mine Deployer"] = "",
    ["Mine Eater!"] = "Pożeracz min!",
    ["|- Mines Time:"] = "|- Czas detonacji min:",
    ["MISSION FAILED"] = "MISJA ZAKOŃCZONA NIEPOWODZENIEM", 
    ["MISSION SUCCESSFUL"] = "MISJA POWIODŁA SIĘ",  
    ["MISSION SUCCESS"] = "MISJA ZAKOŃCZONA SUKCESEM",
    ["Movement: [Up], [Down], [Left], [Right]"] = "Poruszanie się: [Góra], [Dół], [Lewo], [Prawo]",
    ["Multi-shot!"] = "Wielokrotny strzał",
    ["Nameless Heroes"] = "Bezimienni Bohaterowie",
    ["New Barrels Per Turn"] = "Ilość beczek dodanych co turę",
    ["NEW CLAN RECORD: "] = "NOWY REKORD ZESPOŁU: ",
    ["NEW fastest lap: "] = "NOWE najszybsze okrążenie: ",
    ["New Mines Per Turn"] = "Ilość min dodanych co turę",
    ["NEW RACE RECORD: "] = "NOWY REKORD WYŚCIGU: ",
    ["Newton's Hammock"] = "Hamak Newtona",
    ["NOT ENOUGH WAYPOINTS"] = "ZA MAŁO PUNKTÓW KONTROLNYCH",
    ["Not So Friendly Match"] = "Mecz Nie-Do-Końca Towarzyski",  
    ["Oh no! Just try again!"] = "Ojojoj! Spróbuj jeszcze raz!", 
    ["Oh no! Time's up! Just try again."] = "Ajajaj! Koniec czasu! Spróbuj jeszcze raz.",  
    ["Operation Diver"] = "Operacja Nurek",
    ["Opposing Team: "] = "Przeciwna drużyna",
    ["Pathetic Hog #%d"] = "Żałosny Jeż #%d",
--      ["Pathetic Resistance"] = "", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_Newton_and_the_Hammock
    ["Per-Hog Ammo"] = "Oddzielna amunicja dla jeży",
    ["Place more waypoints using [ENTER]"] = "Postaw więcej punktów orientacyjnych za pomocą [Enteru]",
    ["Place more waypoints using the 'Air Attack' weapon."] = "Postaw więcej punktów orientacyjnych używając [Nalotu]",
    ["points"] = "punkty", -- Control, CTF_Blizzard, Basic_Training_-_Bazooka, Basic_Training_-_Shotgun, Basic_Training_-_Sniper_Rifle
    ["Poison"] = "Truciciel",
    ["Power Remaining"] = "pkt. energii pozostało",
    ["Prepare yourself"] = "Przygotuj się",
    ["Press [Precise] to skip intro"] = "Naciśnij [Precyzyjne celowanie] by pominąć intro",
    ["Race complexity limit reached."] = "Osiągnięto limit złożoności trasy.",
    ["RACER"] = "WYŚCIG",
    [" - Return the enemy flag to your base to score | - First team to 3 captures wins | - You may only score when your flag is in your base | - Hogs will drop the flag if killed, or drowned | - Dropped flags may be returned or recaptured | - Hogs respawn when killed"] = " - Przynieś flagę wroga do swojej bazy by zdobyć punkt | - Pierwszy kto zrobi to 3 razy, wygrywa | - Punkt zdobywasz tylko gdy twoja flaga znajduje się w bazie | - Jeże upuszczą flagę gdy zostaną zabite bądź utopione | - Upuszczona flaga może być przywrócona lub przechwycona ponownie | - Jeże odradzają się po śmierci",
    ["Round Limit:"] = "Ilość rund:",
    ["Round Limit"] = "Ilość rund",
    ["Rounds Complete: "] = "Ukończono rund: ",
    ["Rounds Complete"] = "Koniec",
    ["RULES OF THE GAME [Press ESC to view]"] = "ZASADY GRY [Naciśnij ESC by zobaczyć]",        
    ["Save as many hapless hogs as possible!"] = "Uratuj jak najwięcej nieszczęsnych jeży",
    ["SCORE"] = "PUNKTY",
    ["sec"] = "sek",
    ["See ya!"] = "Do zobaczenia!",
    ["selected!"] = "wybrany!",
    ["Shield boosted! +30 power"] = "Osłona ulepszona: +30 energii",
    ["Shield Depleted"] = "Straciłeś Osłonę",
    ["Shield is fully recharged!"] = "Osłona całkowicie naładowana",
    ["Shield Master!"] = "Mistrz Osłony!",
    ["Shield Miser!"] = "Osłonowy skąpiec!",
    ["Shield OFF:"] = "Osłona WYŁĄCZONA:",
    ["Shield ON:"] = "Osłona WŁĄCZONA:",
    ["Shield Seeker!"] = "Zdobywca osłon!",
    ["Shotgun Team"] = "Strzelcy",
    ["Shotgun Training"] = "Trening strzelecki",
    ["shots remaining."] = "strzałów pozostało.",
    ["Silly"] = "Głuptas",
--      ["Sinky"] = "",
    ["%s is out and Team %d|scored a penalty!| |Score:"] = "%s utonął i drużyna %d|dostała punkt karny!| |Punktacja:", 
    ["%s is out and Team %d|scored a point!| |Score:"] = "%s utonął i drużyna %d|zdobyła punkt!| |Punktacja:",  
    ["Sniper Training"] = "Trening Snajperski",
    ["Sniperz"] = "Snajperzy",
    ["Sponge"] = "Gąbka",
    ["Spooky Tree"] = "Straszne drzewo",
    ["s|"] = "s|",
    ["s"] = "s", -- GaudyRacer, Space_Invasion
    ["STATUS UPDATE"] = "WYNIKI", -- GaudyRacer, Space_Invasion
    ["Switched to "] = "Przełączono na ",
    ["Team %d: "] = "Drużyna %d: ",
    ["Team Scores"] = "Punktacja(?)", -- Control, Space_Invasion
--      ["That Sinking Feeling"] = "",
    ["That was pointless."] = "To było bezcelowe",
    ["The enemy is hiding out on yonder ducky!"] = "Na tamtej kaczce ukrywa się nasz przeciwnik!",
    ["The flag will respawn next round."] = "Flaga pojawi się ponownie przy następnej rundzie.",
    ["The Nameless One"] = "Bezimienny",
    ["THE SPECIALISTS"] = "SPECJALIŚCI",
--      ["This one's tricky."] = "",
--      ["This rain is really something..."] = "",
    ["TIME: "] = "CZAS: ",
--      ["Timed Kamikaze!"] = "",
    ["Time Extended!"] = "Więcej Czasu!",
    ["Time Extension"] = "Dodatkowy Czas!",
    ["Toggle Shield"] = "Wł/Wył Osłonę",
    ["Toxic Team"] = "Toksyczny zespół", 
    ["TRACK COMPLETED"] = "UKOŃCZONO TRASĘ",
    ["TRACK FAILED!"] = "TRASA NIEUKOŃCZONA!",
    ["TrophyRace"] = "TrophyRace",
    ["T_T"] = "T_T",
--      ["Tumbling Time Extended!"] = "",
    ["Turn Time"] = "Długość Tury",
    ["Unit"] = "Jednostka",
    ["Unit 3378"] = "Jednostka 3378",
    ["Unit 835"] = "Jednostka 835",
--      ["Unlimited Attacks"] = "",
    ["Unstoppable!"] = "Nie do zatrzymania!",
--      ["User Challenge"] = "",
    ["Use your rope to get from start to finish as fast as you can!"] = "Użyj liny by jak najszybciej dotrzeć od startu do mety",
    ["Victory for the "] = "Zwycięstwo przypadło",
    ["Waypoint placed."] = "Postawiono punkt kontrolny",
    ["Way-Points Remaining"] = "Pozostało punktów: ",
    ["Weapons Reset"] = "Bronie odnawiają się",
    ["Well done."] = "Dobra robota",
    ["Will this ever end?"] = "Co to się kiedyś skończy?",
    ["WINNING TIME: "] = "ZWYCIĘSKI CZAS: ",
    ["You'd almost swear the water was rising!"] = "Przysiągłbym, że woda zdaje się podnosić!",
    ["You have SCORED!!"] = "Zdobyłeś PUNKT",
    ["You saved"] = "Uratowałeś",
    ["You've failed. Try again."] = "Przegrałeś. Spróbuj jeszcze raz",
    ["You've reached the goal!| |Time: "] = "Dotarłeś do celu!| |Czas: ",
    ["'Zooka Team"] = "Bazookinierzy",
    }
